diff src/dnsbl.h @ 249:15bf4f68a0b2

Add dnswl support
author Carl Byington <carl@five-ten-sg.com>
date Sun, 08 Apr 2012 11:42:59 -0700
parents d8ee4c97b9ab
children 836b7f2357f9
line wrap: on
line diff
--- a/src/dnsbl.h	Fri Jan 06 22:07:45 2012 -0800
+++ b/src/dnsbl.h	Sun Apr 08 11:42:59 2012 -0700
@@ -33,7 +33,8 @@
     bool    err;                            // did we get any errors on the resolver socket?
     int32_t ip;                             // ip4 address of the smtp client
     const char      *helo;                  // helo from client
-    map<DNSBLP, bool> checked;              // map of dnsblp to result of (ip listed on that dnsbl)
+    map<DNSBLP, bool> checked_black;        // map of dnsblp to result of (ip listed on that dnsbl)
+    map<DNSWLP, bool> checked_white;        // map of dnswlp to result of (ip listed on that dnswl)
     // message specific data
     const char      *mailaddr;              // envelope from value
     const char      *queueid;               // sendmail queue id